@@ -9,9 +9,11 @@ from ..scraper import _BasicScraper
 
 
 class NineteenNinetySeven(_BasicScraper):
+    description = u'1977 the Comic - Sex, Drugs and Rock and Roll Just Not in That Order'
     name = '1997'
     url = 'http://www.1977thecomic.com/'
-    stripUrl = url + '%s'
+    stripUrl = url + '%s/'
+    firstStripUrl = stripUrl % '1977-comics/from-the-beginning-part-1'
     imageSearch = compile(tagre("img", "src", r'(http://www\.1977thecomic\.com/comics-1977/[^"]+)'))
     prevSearch = compile(tagre("a", "href", r'([^"]+)')+"Previous")
     help = 'Index format: yyyy/mm/dd/strip-name'
