@@ -13,9 +13,12 @@ class xkcd(_BasicScraper):
     url = 'http://xkcd.com/'
     starter = bounceStarter(url, compile(tagre("a", "href", r'(/\d+/)', before="next")))
     stripUrl = url + '%s/'
+    firstStripUrl = stripUrl % '1'
     imageSearch = compile(tagre("img", "src", r'(http://imgs\.xkcd\.com/comics/[^"]+)'))
     prevSearch = compile(tagre("a", "href", r'(/\d+/)', before="prev"))
     help = 'Index format: n (unpadded)'
+    description = u'A webcomic of romance, sarcasm, math, and language.'
+    adult = True
 
     @classmethod
     def namer(cls, imageUrl, pageUrl):
