@@ -1,6 +1,7 @@
 # Copyright (C) 2012-2013 Bastian Kleineidam
 import re
 import json
+from dosagelib.util import unescape, unquote, asciify
 
 def contains_case_insensitive(adict, akey):
     """Check if key is in adict. The search is case insensitive."""
@@ -13,7 +14,7 @@ def contains_case_insensitive(adict, akey):
 _tagre = re.compile(r"<.+?>")
 def remove_html_tags(text):
     """Remove all HTML tags from text."""
-    return _tagre.sub("", text)
+    return _tagre.sub(u"", text)
 
 
 def capfirst(text):
@@ -23,12 +24,12 @@ def capfirst(text):
     return text[0].upper() + text[1:]
 
 
-_ws = re.compile(r"\s+")
+_ws = re.compile(ur"\s+")
 def compact_whitespace(text):
     """Compact all subsequent whitespace to a single space."""
     if not text:
         return text
-    return _ws.sub(" ", text)
+    return _ws.sub(u" ", text)
 
 
 def save_result(res, json_file):
@@ -46,3 +47,20 @@ def load_result(json_file):
 def truncate_name(text):
     """Ensure the comic name does not exceed 100 characters."""
     return text[:100]
+
+
+def format_name(text):
+    """Format a comic name."""
+    name = unescape(text)
+    name = asciify(name.replace(u'&', u'And').replace(u'@', u'At'))
+    name = capfirst(name)
+    return name
+
+
+def format_description(text):
+    """Format a comic description."""
+    desc = remove_html_tags(text)
+    desc = unescape(desc)
+    desc = unquote(desc)
+    desc = compact_whitespace(desc).strip()
+    return desc
